==> aws-android-sdk-cognitoidentityprovider-2.2.19-sources.jar: com/amazonaws/services/cognitoidentityprovider/model/transform/AdminUpdateUserAttributesResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitoidentityprovider.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.cognitoidentityprovider.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * Admin Update User Attributes Result JSON Unmarshaller
 */
public class AdminUpdateUserAttributesResultJsonUnmarshaller implements Unmarshaller<AdminUpdateUserAttributesResult, JsonUnmarshallerContext> {

    public AdminUpdateUserAttributesResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        AdminUpdateUserAttributesResult adminUpdateUserAttributesResult = new AdminUpdateUserAttributesResult();

        return adminUpdateUserAttributesResult;
    }

    private static AdminUpdateUserAttributesResultJsonUnmarshaller instance;
    public static AdminUpdateUserAttributesResultJsonUnmarshaller getInstance() {
        if (instance == null) instance = new AdminUpdateUserAttributesResultJsonUnmarshaller();
        return instance;
    }
}

==> aws-android-sdk-cognitoidentityprovider-2.16.1-sources.jar: com/amazonaws/services/cognitoidentityprovider/model/transform/AdminUpdateUserAttributesResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitoidentityprovider.model.transform;

import com.amazonaws.services.cognitoidentityprovider.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for response AdminUpdateUserAttributesResult
 */
public class AdminUpdateUserAttributesResultJsonUnmarshaller implements
        Unmarshaller<AdminUpdateUserAttributesResult, JsonUnmarshallerContext> {

    public AdminUpdateUserAttributesResult unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        AdminUpdateUserAttributesResult adminUpdateUserAttributesResult = new AdminUpdateUserAttributesResult();

        return adminUpdateUserAttributesResult;
    }

    private static AdminUpdateUserAttributesResultJsonUnmarshaller instance;

    public static AdminUpdateUserAttributesResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new AdminUpdateUserAttributesResultJsonUnmarshaller();
        return instance;
    }
}
